ProcessedTuple
==============

.. currentmodule:: pykeen.datasets.ea.combination

.. autoclass:: ProcessedTuple
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ProcessedTuple.alignment
      ~ProcessedTuple.mapped_triples
      ~ProcessedTuple.translation_kwargs

   .. rubric:: Attributes Documentation

   .. autoattribute:: alignment
   .. autoattribute:: mapped_triples
   .. autoattribute:: translation_kwargs
